@@ -1,8 +1,8 @@
 """pytest-bdd public API."""
 
-from pytest_bdd.steps import given, when, then
 from pytest_bdd.scenario import scenario, scenarios
+from pytest_bdd.steps import given, then, when
 
-__version__ = "4.1.0"
+__version__ = "5.0.0"
 
 __all__ = [given.__name__, when.__name__, then.__name__, scenario.__name__, scenarios.__name__]
